# eric7.EricCore

Package implementing some special Core elements.

They extend or amend the standard elements as found in QtCore.

### Modules

EricFileSystemWatcher | Module implementing a QFileSystemWatcher replacement based on the 'watchdog' package.
EricStdRedirector | Module implementing a redirector for stderr and stdout to be able to send data written to these streams via Qt signals.
EricTreeSortFilterProxyModel | Module implementing a modified QSortFilterProxyModel.